@@ -1,25 +1,19 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-# vim: ai ts=4 sts=4 et sw=4 nu
-
-
-""" quick script to fix videojs-ogvjs so that it triggers on webm mimetype """
+"""quick script to fix videojs-ogvjs so that it triggers on webm mimetype"""
 
 import logging
 import pathlib
 import sys
-from typing import Union
 
 logging.basicConfig(format="%(levelname)s:%(message)s", level=logging.DEBUG)
 logger = logging.getLogger(__name__)
 
 
-def fix_source_dir(source_vendors_path: Union[pathlib.Path, str]):
+def fix_source_dir(source_vendors_path: pathlib.Path | str):
     """update ogvjs plugin to trigger on webm mimetype"""
     root = pathlib.Path(source_vendors_path)
     logger.info("fixing videosjs-ogvjs.js")
     plugin_path = root.joinpath("videojs-ogvjs.js")
-    with open(plugin_path, "r") as fp:
+    with open(plugin_path) as fp:
         content = fp.read()
 
     content = content.replace(
@@ -34,16 +28,17 @@ def fix_source_dir(source_vendors_path: Union[pathlib.Path, str]):
     logger.info("all done.")
 
 
-def run():
-    if len(sys.argv) < 2:
-        print(f"Usage: {sys.argv[0]} <source_vendors_path>")
-        print(
+def run(args: list[str] = sys.argv):
+    if len(args) < 2:  # noqa: PLR2004
+        print(f"Usage: {args[0]} <source_vendors_path>")  # noqa: T201
+        print(  # noqa: T201
             "\t<source_vendors_path>\tpath to your folder containing "
             "ogvjs/videojs/videojs-ogvjs."
         )
-        sys.exit(1)
-    return sys.exit(fix_source_dir(sys.argv[1]))
+        return 1
+    fix_source_dir(args[1])
+    return 0
 
 
 if __name__ == "__main__":
-    run()
+    sys.exit(run())
