@@ -1,15 +1,16 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# vim: ai ts=4 sts=4 et sw=4 nu
-
+import io
 import pathlib
-from typing import Optional
+from typing import IO, Any
 
-from PIL import Image
+from PIL.Image import Image
+from PIL.ImageFile import ImageFile
 
 
 def save_image(
-    src: Image, dst: pathlib.Path, fmt: Optional[str] = None, **params: Optional[dict]
+    src: Image | ImageFile,
+    dst: pathlib.Path | IO[bytes] | io.BytesIO,
+    fmt: str,
+    **params: Any,
 ) -> None:
     """PIL.Image.save() wrapper setting default parameters"""
     args = {"JPEG": {"quality": 100}, "PNG": {}}.get(fmt, {})
