@@ -1,32 +1,32 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-# vim: ai ts=4 sts=4 et sw=4 nu
-
 import io
 import logging
 import pathlib
 import sys
+from collections.abc import Iterable
 from logging.handlers import RotatingFileHandler
-from typing import Iterable, Optional
+from typing import TextIO
 
-from .constants import NAME
+from zimscraperlib.constants import NAME
 
 DEFAULT_FORMAT = "[%(name)s::%(asctime)s] %(levelname)s:%(message)s"
+DEFAULT_FORMAT_WITH_THREADS = (
+    "[%(name)s::%(threadName)s::%(asctime)s] %(levelname)s:%(message)s"
+)
 VERBOSE_DEPENDENCIES = ["urllib3", "PIL", "boto3", "botocore", "s3transfer"]
 
 
-def getLogger(
+def getLogger(  # noqa: N802 (intentionally matches the stdlib getLogger name)
     name: str,
-    level: Optional[int] = logging.INFO,
-    console: Optional[io.TextIOBase] = sys.stdout,
-    log_format: Optional[str] = DEFAULT_FORMAT,
-    file: Optional[pathlib.Path] = False,
-    file_level: Optional[int] = None,
-    file_format: Optional[str] = None,
-    file_max: Optional[int] = 2**20,
-    file_nb_backup: Optional[int] = 1,
-    deps_level: Optional[int] = logging.WARNING,
-    additional_deps: Optional[Iterable] = None,
+    level: int = logging.INFO,
+    console: TextIO | io.StringIO | None = sys.stdout,
+    log_format: str | None = DEFAULT_FORMAT,
+    file: pathlib.Path | None = None,
+    file_level: int | None = None,
+    file_format: str | None = None,
+    file_max: int = 2**20,
+    file_nb_backup: int = 1,
+    deps_level: int = logging.WARNING,
+    additional_deps: Iterable[str] | None = None,
 ):
     """configured logger for most usages
 
@@ -40,7 +40,8 @@ def getLogger(
     - deps_level: log level for idendified verbose dependencies
     - additional_deps: additional modules names of verbose dependencies
         to assign deps_level to"""
-    if additional_deps is None:
+
+    if not additional_deps:
         additional_deps = []
 
     # align zimscraperlib logging level to that of scraper
@@ -48,8 +49,8 @@ def getLogger(
 
     # set arbitrary level for some known verbose dependencies
     # prevents them from polluting logs
-    for logger_name in set(VERBOSE_DEPENDENCIES + additional_deps):
-        logging.getLogger(logger_name).setLevel(logging.WARNING)
+    for logger_name in set(VERBOSE_DEPENDENCIES + list(additional_deps)):
+        logging.getLogger(logger_name).setLevel(deps_level)
 
     logger = logging.Logger(name)
     logger.setLevel(logging.DEBUG)
@@ -63,7 +64,9 @@ def getLogger(
 
     if file:
         file_handler = RotatingFileHandler(
-            file, maxBytes=file_max, backupCount=file_nb_backup
+            file,
+            maxBytes=file_max,
+            backupCount=file_nb_backup,
         )
         file_handler.setFormatter(logging.Formatter(file_format or log_format))
         file_handler.setLevel(file_level or level)
@@ -72,9 +75,9 @@ def getLogger(
     return logger
 
 
-def nicer_args_join(args: Iterable) -> str:
+def nicer_args_join(args: list[str]) -> str:
     """slightly better concateated list of subprocess args for display"""
     nargs = args[0:1]
     for arg in args[1:]:
-        nargs.append(arg if arg.startswith("-") else '"{}"'.format(arg))
+        nargs.append(arg if arg.startswith("-") else f'"{arg}"')
     return " ".join(nargs)
