@@ -1,8 +1,6 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-# vim: ai ts=4 sts=4 et sw=4 nu
+from typing import ClassVar
 
-from .config import Config
+from zimscraperlib.video.config import Config
 
 preset_type = "video"
 
@@ -19,11 +17,12 @@ class VoiceMp3Low(Config):
     ext = "mp3"
     mimetype = "audio/mp3"
 
-    options = {
+    options: ClassVar[dict[str, str | None]] = {
         "-vn": "",  # remove video stream
         "-codec:a": "mp3",  # audio codec
         "-ar": "44100",  # audio sampling rate
         "-b:a": "48k",  # target audio bitrate
+        "-ac": "2",  # force stereo
     }
 
 
@@ -31,27 +30,27 @@ class VideoWebmLow(Config):
     """Low Quality webm video
 
     480:h format with height adjusted to keep aspect ratio
-    300k video bitrate
-    48k audio bitrate
-    highly degraded quality (30, 42)"""
+    128k target video bitrate but stay within quality boundaries.
+    48k audio bitrate"""
 
-    VERSION = 1
+    VERSION = 3
 
     ext = "webm"
     mimetype = f"{preset_type}/webm"
 
-    options = {
-        "-codec:v": "libvpx",  # video codec
-        "-quality": "best",  # codec preset
-        "-b:v": "300k",  # target video bitrate
-        "-maxrate": "300k",  # max video bitrate
-        "-minrate": "300k",  # min video bitrate
-        "-qmin": "30",  # min quantizer scale
-        "-qmax": "42",  # max quantizer scale
+    options: ClassVar[dict[str, str | None]] = {
+        "-codec:v": "libvpx-vp9",  # video codec
+        "-b:v": "140k",  # Adjust quantizer within min/max to target this bitrate
+        "-qmin": "30",  # Reduce the bitrate on very still videos
+        "-qmax": "40",  # Increase the bitrate on very busy videos
+        "-g": "240",  # Number of frames allowed between keyframes
+        "-quality": "good",  # codec preset
+        "-speed": "4",  # Encoding speed (compromise between quality and encoding time)
         "-vf": "scale='480:trunc(ow/a/2)*2'",  # frame size
         "-codec:a": "libvorbis",  # audio codec
-        "-ar": "44100",  # audio sampling rate
         "-b:a": "48k",  # target audio bitrate
+        "-ar": "44100",  # audio sampling rate
+        "-ac": "2",  # force stereo
     }
 
 
@@ -68,7 +67,7 @@ class VideoMp4Low(Config):
     ext = "mp4"
     mimetype = f"{preset_type}/mp4"
 
-    options = {
+    options: ClassVar[dict[str, str | None]] = {
         "-codec:v": "h264",  # video codec
         "-b:v": "300k",  # target video bitrate
         "-maxrate": "300k",  # max video bitrate
@@ -80,6 +79,7 @@ class VideoMp4Low(Config):
         "-ar": "44100",  # audio sampling rate
         "-b:a": "48k",  # target audio bitrate
         "-movflags": "+faststart",  # extra flag
+        "-ac": "2",  # force stereo
     }
 
 
@@ -88,16 +88,23 @@ class VideoWebmHigh(Config):
 
     25 constant quality"""
 
-    VERSION = 1
+    VERSION = 2
 
     ext = "webm"
     mimetype = f"{preset_type}/webm"
 
-    options = {
-        "-codec:v": "libvpx",  # video codec
+    options: ClassVar[dict[str, str | None]] = {
+        "-codec:v": "libvpx-vp9",  # video codec
+        "-b:v": "340k",  # Adjust quantizer within min/max to target this bitrate
+        "-qmin": "26",  # Reduce the bitrate on very still videos
+        "-qmax": "54",  # Increase the bitrate on very busy videos
+        "-g": "240",  # Number of frames allowed between keyframes
+        "-quality": "good",  # codec preset
+        "-speed": "1",  # Encoding speed (compromise between quality and encoding time)
         "-codec:a": "libvorbis",  # audio codec
-        "-crf": "25",  # constant quality, lower value gives better qual and larger size
-        "-b:v": "0",  # must be passed if using constant quality mode via -cbr for codec
+        "-b:a": "48k",  # target audio bitrate
+        "-ar": "44100",  # audio sampling rate
+        "-ac": "2",  # force stereo
     }
 
 
@@ -111,7 +118,7 @@ class VideoMp4High(Config):
     ext = "mp4"
     mimetype = f"{preset_type}/mp4"
 
-    options = {
+    options: ClassVar[dict[str, str | None]] = {
         "-codec:v": "h264",  # video codec
         "-codec:a": "aac",  # audio codec
         "-crf": "20",  # constant quality, lower value gives better qual and larger size
