@@ -1,12 +1,8 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-# vim: ai ts=4 sts=4 et sw=4 nu
-
-
+import pathlib
 import subprocess
 
 
-def get_media_info(src_path):
+def get_media_info(src_path: pathlib.Path):
     """dict of file's details from ffprobe
 
     codecs: list of codecs in use
@@ -14,6 +10,7 @@ def get_media_info(src_path):
     bitrate: file's main bitrate"""
 
     args = [
+        "/usr/bin/env",
         "ffprobe",
         "-i",
         f"file:{src_path}",
@@ -28,9 +25,8 @@ def get_media_info(src_path):
     ]
     ffprobe = subprocess.run(
         args,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        universal_newlines=True,
+        capture_output=True,
+        text=True,
         check=False,
     )
     result = ffprobe.stdout.strip().split("\n")
